EditState class

A document and where the caret is in it.

Constructors

EditState(String value, int start, int end)
Creates a state.
const

Properties

end → int
Where it ends. The same as start for a caret.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Where the selection begins.
final
value → String
The Markdown.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited